@@ -479,9 +479,16 @@ QString QHexEdit::selectedData()
 
 void QHexEdit::setFont(const QFont &font)
 {
-    QWidget::setFont(font);
-    _pxCharWidth = fontMetrics().width(QLatin1Char('2'));
-    _pxCharHeight = fontMetrics().height();
+    QFont theFont(font);
+    theFont.setStyleHint(QFont::Monospace);
+    QWidget::setFont(theFont);
+    QFontMetrics metrics = fontMetrics();
+#if QT_VERSION > QT_VERSION_CHECK(5, 11, 0)
+    _pxCharWidth = metrics.horizontalAdvance(QLatin1Char('2'));
+#else
+    _pxCharWidth = metrics.width(QLatin1Char('2'));
+#endif
+    _pxCharHeight = metrics.height();
     _pxGapAdr = _pxCharWidth / 2;
     _pxGapAdrHex = _pxCharWidth;
     _pxGapHexAscii = 2 * _pxCharWidth;
@@ -845,6 +852,7 @@ void QHexEdit::keyPressEvent(QKeyEvent *event)
     }
 
     refresh();
+    QAbstractScrollArea::keyPressEvent(event);
 }
 
 void QHexEdit::mouseMoveEvent(QMouseEvent * event)
@@ -902,7 +910,7 @@ void QHexEdit::paintEvent(QPaintEvent *event)
             {
                 address = QString("%1").arg(_bPosFirst + row*_bytesPerLine + _addressOffset, _addrDigits, 16, QChar('0'));
                 painter.setPen(QPen(_addressFontColor));
-                painter.drawText(_pxPosAdrX - pxOfsX, pxPosY, address);
+                painter.drawText(_pxPosAdrX - pxOfsX, pxPosY, _hexCaps ? address.toUpper() : address);
             }
         }
 
@@ -951,7 +959,7 @@ void QHexEdit::paintEvent(QPaintEvent *event)
                 if (_asciiArea)
                 {
                     int ch = (uchar)_dataShown.at(bPosLine + colIdx);
-					if (ch < ' ' || ch > '~')
+                    if (ch < ' ' || ch > '~')
                         ch = '.';
                     r.setRect(pxPosAsciiX2, pxPosY - _pxCharHeight + _pxSelectionSub, _pxCharWidth, _pxCharHeight);
                     painter.fillRect(r, (c == _brushSelection.color() || c == _brushHighlighted.color()) ? c : _asciiAreaColor);
@@ -965,51 +973,50 @@ void QHexEdit::paintEvent(QPaintEvent *event)
         painter.setPen(viewport()->palette().color(QPalette::WindowText));
     }
 
-	// _cursorPosition counts in 2, _bPosFirst counts in 1
-	int hexPositionInShowData = _cursorPosition - 2 * _bPosFirst;
+    // _cursorPosition counts in 2, _bPosFirst counts in 1
+    int hexPositionInShowData = _cursorPosition - 2 * _bPosFirst;
 
-	// due to scrolling the cursor can go out of the currently displayed data
-	if ((hexPositionInShowData >= 0) && (hexPositionInShowData < _hexDataShown.size()))
-	{
-		// paint cursor
+    // due to scrolling the cursor can go out of the currently displayed data
+    if ((hexPositionInShowData >= 0) && (hexPositionInShowData < _hexDataShown.size()))
+    {
+        // paint cursor
 		if (!_readOnly)
-		{
+        {
 			QColor color;
 
 			if (_blink && hasFocus())
 			{
 				color = viewport()->palette().color(QPalette::WindowText);
-			}
-			else
-			{
+            }
+            else
+            {
 				if (_editAreaIsAscii)
 					color = _asciiAreaColor;
 				else
 					color = viewport()->palette().color(QPalette::Base);
-			}
+            }
 			painter.fillRect(_cursorRect, color);
 		}
 		else
 		{
 			painter.fillRect(QRect(_pxCursorX - pxOfsX, _pxCursorY - _pxCharHeight + _pxSelectionSub, _pxCharWidth, _pxCharHeight), viewport()->palette().dark().color());
-			if (_editAreaIsAscii)
-			{
-				// every 2 hex there is 1 ascii
-				int asciiPositionInShowData = hexPositionInShowData / 2;
+            if (_editAreaIsAscii)
+            {
+                // every 2 hex there is 1 ascii
+                int asciiPositionInShowData = hexPositionInShowData / 2;
+                int ch = (uchar)_dataShown.at(asciiPositionInShowData);
+                if (ch < ' ' || ch > '~')
+                    ch = '.';
 
-				int ch = (uchar)_dataShown.at(asciiPositionInShowData);
-				if (ch < ' ' || ch > '~')
-					ch = '.';
-
-				painter.drawText(_pxCursorX - pxOfsX, _pxCursorY, QChar(ch));
-			}
-			else
-			{
+                painter.drawText(_pxCursorX - pxOfsX, _pxCursorY, QChar(ch));
+            }
+            else
+            {
 				QByteArray hex = _hexDataShown.mid(hexPositionInShowData, 1);
 				painter.drawText(_pxCursorX - pxOfsX, _pxCursorY, _hexCaps ? hex.toUpper() : hex);
 			}
-		}
-	}
+        }
+    }
 
     // emit event, if size has changed
     if (_lastEventSize != _chunks->size())
@@ -1031,11 +1038,11 @@ void QHexEdit::resizeEvent(QResizeEvent *)
             pxFixGaps += _pxGapHexAscii;
 
         // +1 because the last hex value do not have space. so it is effective one char more
-        int charWidth = (viewport()->width() - pxFixGaps ) / _pxCharWidth + 1; 
+        int charWidth = (viewport()->width() - pxFixGaps ) / _pxCharWidth + 1;
 
         // 2 hex alfa-digits 1 space 1 ascii per byte = 4; if ascii is disabled then 3
         // to prevent devision by zero use the min value 1
-        setBytesPerLine(std::max(charWidth / (_asciiArea ? 4 : 3),1));  
+        setBytesPerLine(std::max(charWidth / (_asciiArea ? 4 : 3),1));
     }
     adjust();
 }
@@ -1197,9 +1204,9 @@ QString QHexEdit::toReadable(const QByteArray &ba)
 
 void QHexEdit::updateCursor()
 {
-	if (_blink)
-		_blink = false;
-	else
-	   _blink = true;
-	viewport()->update(_cursorRect);
+    if (_blink)
+        _blink = false;
+    else
+        _blink = true;
+    viewport()->update(_cursorRect);
 }
